@@ -1,17 +1,13 @@
 package backrest
 
 import (
-	"github.com/go-kit/log"
+	"log/slog"
+
 	"github.com/prometheus/client_golang/prometheus"
 	"github.com/prometheus/client_golang/prometheus/promauto"
 )
 
 var (
-	pgbrExporterInfoMetric = promauto.NewGaugeVec(prometheus.GaugeOpts{
-		Name: "pgbackrest_exporter_info",
-		Help: "Information about pgBackRest exporter.",
-	},
-		[]string{"version"})
 	pgbrExporterStatusMetric = promauto.NewGaugeVec(prometheus.GaugeOpts{
 		Name: "pgbackrest_exporter_status",
 		Help: "pgBackRest exporter get data status.",
@@ -19,22 +15,9 @@ var (
 		[]string{"stanza"})
 )
 
-// Set exporter info metrics:
-//   - pgbackrest_exporter_info
-func getExporterMetrics(exporterVer string, setUpMetricValueFun setUpMetricValueFunType, logger log.Logger) {
-	setUpMetric(
-		pgbrExporterInfoMetric,
-		"pgbackrest_exporter_info",
-		1,
-		setUpMetricValueFun,
-		logger,
-		exporterVer,
-	)
-}
-
 // Set exporter metrics:
 //   - pgbackrest_exporter_status
-func getExporterStatusMetrics(stanzaName string, getDataStatus bool, setUpMetricValueFun setUpMetricValueFunType, logger log.Logger) {
+func getExporterStatusMetrics(stanzaName string, getDataStatus bool, setUpMetricValueFun setUpMetricValueFunType, logger *slog.Logger) {
 	// If the information is collected for all available stanzas,
 	// the value of the label 'stanza' will be 'all-stanzas',
 	// otherwise the stanza name will be set.
